from datetime import datetime
from sqlalchemy import Column, Integer, DateTime
from models.base import Base, Session, logger

class TimestampTracker(Base):
    __tablename__ = 'timestamp_tracker'
    
    id = Column(Integer, primary_key=True)
    last_timestamp = Column(DateTime)
    
    @classmethod
    def get_last_timestamp(cls):
        session = Session()
        try:
            tracker = session.query(cls).first()
            return tracker.last_timestamp if tracker else None
        except Exception as e:
            logger.error(f"Error getting last timestamp: {str(e)}")
            return None
        finally:
            session.close()

    @classmethod
    def update_last_timestamp(cls, timestamp):
        session = Session()
        try:
            tracker = session.query(cls).first()
            if not tracker:
                tracker = cls(last_timestamp=timestamp)
                session.add(tracker)
            else:
                tracker.last_timestamp = timestamp
            session.commit()
        except Exception as e:
            logger.error(f"Error updating timestamp: {str(e)}")
            session.rollback()
            raise
        finally:
            session.close()
